@@ -56,10 +56,8 @@ public:
 class BitReader
 {
 public:
-    BitReader(const QByteArray& d) : pos(0), data(d)
-    {
-        data.append("\000\000\000\000");    //krazy:exclude=strings
-        len=data.size()*8;
+    BitReader(const QByteArray& d) : pos(0), len(d.size() * 8), data(d) {
+        data.append(4, '\0');
     }
     
     quint32 read() {
@@ -140,9 +138,13 @@ QByteArray RLEDecompressor::decompress(const QByteArray& data)
                                         N+=(unsigned char)data.at(i++);
 					copyLength = (N & 7) + 3;
 					shift = (N & 0x3fff) / 8;
-					shifted = ret.size()-shift;
-					if (shifted>(ret.size()-1)) goto endOfLoop;
-					for (int i=0;i<copyLength;i++) ret.append(ret.at(shifted+i));
+					if ((shift < 1) || (shift > ret.size())) {
+						return ret;
+					}
+					shifted = ret.size() - shift;
+					for (int i = shifted; i < shifted + copyLength; i++) {
+						ret.append(ret.at(i));
+					}
 					break;
 			}
 		}
@@ -229,12 +231,12 @@ fail:
     valid=false;
 }
 
-Decompressor* Decompressor::create(quint8 type, const PDB& pdb) 
+std::unique_ptr<Decompressor> Decompressor::create(quint8 type, const PDB& pdb)
 {
         switch (type) {
-            case 1 : return new NOOPDecompressor(pdb); 
-            case 2 : return new RLEDecompressor(pdb); 
-            case 'H' : return  new HuffdicDecompressor(pdb);
+            case 1 : return std::make_unique<NOOPDecompressor>(pdb);
+            case 2 : return std::make_unique<RLEDecompressor>(pdb);
+            case 'H' : return  std::make_unique<HuffdicDecompressor>(pdb);
             default : return nullptr;
         }
 
